﻿using CRUD_Dapper.CRUDService;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Windows.Forms;

namespace CRUD_Dapper
{
    public partial class Form1 : MetroFramework.Forms.MetroForm
    {
        public Form1()
        {
            InitializeComponent();
            this.StyleManager = msmMain;
            msmMain.Theme = MetroFramework.MetroThemeStyle.Dark;
        }

        EntityState oStatus = EntityState.Unchanged;

        private void Form1_Load(object sender, EventArgs e)
        {
            try
            {
                FuncionariosServiceSoapClient funci = new FuncionariosServiceSoapClient();
                funcionarioBindingSource.DataSource = funci.GetAll();

                pContainer.Enabled = false;
                Funcionario ofunci = funcionarioBindingSource.Current as Funcionario;
                if (ofunci != null)
                {
                    if (!string.IsNullOrEmpty(ofunci.ImagemUrl))
                        picFoto.Image = Image.FromFile(ofunci.ImagemUrl);
                }
            }
            catch(Exception ex)
            {
                MetroFramework.MetroMessageBox.Show(this, ex.Message,"Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnProcurar_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog ofd = new OpenFileDialog() { Filter = "JPEG|*.jpg|PNG|*.png", ValidateNames = true })
            {
                if(ofd.ShowDialog() == DialogResult.OK)
                {
                    picFoto.Image = Image.FromFile(ofd.FileName);
                    Funcionario ofunci = funcionarioBindingSource.Current as Funcionario;
                    if (ofunci != null)
                        ofunci.ImagemUrl = ofd.FileName;
                }
            }
        }

        void LimpaControles()
        {
            txtNome.Text = "";
            txtEmail.Text = "";
            txtEndereco.Text = "";
            txtID.Text = "";
            txtCargo.Text = "";
            txtTelefone.Text = "";
        }

        private void btnAdicionar_Click(object sender, EventArgs e)
        {
            try
            {
                oStatus = EntityState.Added;
                picFoto.Image = null;
                pContainer.Enabled = true;
                List<Funcionario> lista = ((IEnumerable<Funcionario>)funcionarioBindingSource.DataSource).ToList();
                funcionarioBindingSource.DataSource = lista.AsEnumerable();
                funcionarioBindingSource.MoveLast();
                funcionarioBindingSource.AddNew();
                LimpaControles();
                txtNome.Focus();
            }
            catch(Exception ex)
            {
                MetroFramework.MetroMessageBox.Show(this, ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnCancelar_Click(object sender, EventArgs e)
        {
            pContainer.Enabled = false;
            funcionarioBindingSource.ResetBindings(false);
            this.Form1_Load(sender,e);
        }

        private void btnEditar_Click(object sender, EventArgs e)
        {
            oStatus = EntityState.Changed;
            pContainer.Enabled = true;
            txtNome.Focus();
        }

        private void gdAlunos_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            try
            {
                Funcionario ofunci = funcionarioBindingSource.Current as Funcionario;
                if (ofunci != null)
                {
                    if (!string.IsNullOrEmpty(ofunci.ImagemUrl))
                        picFoto.Image = Image.FromFile(ofunci.ImagemUrl);
                }
            }
            catch(Exception ex)
            {
                MetroFramework.MetroMessageBox.Show(this, ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void btnDeletar_Click(object sender, EventArgs e)
        {
            oStatus = EntityState.Deleted;
            if (MetroFramework.MetroMessageBox.Show(this, "Tem certeza que deseja Excluir este registro", "Excluir ?", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
            {
                try
                {
                    Funcionario ofunci = funcionarioBindingSource.Current as Funcionario;
                    if (ofunci != null)
                    {
                        FuncionariosServiceSoapClient funci = new FuncionariosServiceSoapClient();
                        bool resultado = funci.Delete(ofunci.FuncionarioID);
                            if (resultado)
                            {
                                funcionarioBindingSource.RemoveCurrent();
                                pContainer.Enabled = false;
                                picFoto.Image = null;
                                oStatus = EntityState.Unchanged;
                            }
                        }
                }
                catch (Exception ex)
                {
                    MetroFramework.MetroMessageBox.Show(this, ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void btnSalvar_Click(object sender, EventArgs e)
        {
                try
                {
                    funcionarioBindingSource.EndEdit();
                    Funcionario ofunci = funcionarioBindingSource.Current as Funcionario;
                    if (ofunci != null)
                    {
                    FuncionariosServiceSoapClient funci = new FuncionariosServiceSoapClient(); 
                            if(oStatus==EntityState.Added)
                            {
                                ofunci.FuncionarioID = funci.Inserir(ofunci);
                            }
                            else if( oStatus==EntityState.Changed)
                            {
                              funci.Update(ofunci);
                            }
                            gdFuncionarios.Refresh();
                            pContainer.Enabled = false;
                            oStatus = EntityState.Unchanged;
                    }
                }
                catch (Exception ex)
                {
                    MetroFramework.MetroMessageBox.Show(this, ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
         }
    }
}
